import { createTokenizationSupport } from './tokenization';

const richEditConfiguration = {
    wordPattern: /(-?\d*\.\d\w*)|([^\[\{\]\}\:\"\,\s]+)/g,

    comments: {
        lineComment: '//',
        blockComment: ['/*', '*/'],
    },

    brackets: [
        ['{', '}'],
        ['[', ']'],
    ],

    autoClosingPairs: [
        { open: '{', close: '}', notIn: ['string'] },
        { open: '[', close: ']', notIn: ['string'] },
        { open: '"', close: '"', notIn: ['string'] },
    ],
};

export const registerLanguages = monaco => {
    monaco.languages.register({
        id: 'json',
        extensions: ['.json', '.bowerrc', '.jshintrc', '.jscsrc', '.eslintrc', '.babelrc'],
        aliases: ['JSON', 'json'],
        mimetypes: ['application/json'],
    });

    monaco.languages.onLanguage('json', () => {
        monaco.languages.setLanguageConfiguration('json', richEditConfiguration);
        monaco.languages.setTokensProvider('json', createTokenizationSupport(false));
    });

    monaco.languages.register({
        id: 'jsonc',
        extensions: ['.jsonc'],
        aliases: ['JSONC', 'jsonc'],
        mimetypes: ['application/json'],
    });

    monaco.languages.onLanguage('jsonc', () => {
        monaco.languages.setLanguageConfiguration('jsonc', richEditConfiguration);
        monaco.languages.setTokensProvider('jsonc', createTokenizationSupport(true));
    });

    monaco.languages.register({
        id: 'jsonc2',
        extensions: ['.jsonc'],
        aliases: ['JSONC', 'jsonc'],
        mimetypes: ['application/json'],
    });

    monaco.languages.onLanguage('jsonc2', () => {
        monaco.languages.setLanguageConfiguration('jsonc2', richEditConfiguration);
        monaco.languages.setTokensProvider('jsonc2', createTokenizationSupport(true));
    });
};

